/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.    
 */
package org.fabric3.introspection.xml;

import javax.xml.stream.XMLStreamReader;

/**
 * Indicates the loader encountered an invalid value.
 *
 * @version $Rev: 4293 $ $Date: 2008-05-22 03:10:37 +0100 (Thu, 22 May 2008) $
 */
public class InvalidValue extends XmlValidationFailure<String> {
    private Throwable cause;

    public InvalidValue(String message, String value, XMLStreamReader reader) {
        super(message, value, reader);
    }

    public InvalidValue(String message, String value, XMLStreamReader reader, Throwable cause) {
        super(message, value, reader);
        this.cause = cause;
    }

    public Throwable getCause() {
        return cause;
    }

    public String getMessage() {
        if (cause != null) {
            return super.getMessage() + ". The original error was: \n" + cause.toString();
        } else {
            return super.getMessage();
        }
    }
}
